@@ -47,7 +47,7 @@
 #endif
 
 #define KE_TIME_WAIT 			5000
-#define COUNT_OF_ITEM_IN_LAYER_KEYSET 	16
+#define COUNT_OF_ITEM_IN_LAYER_KEYSET 	17
 
 #define MODIFIER(K,C) (K ? C : "")
 #define LINE(X)       (X != 0 ? "-" : "")
@@ -384,6 +384,11 @@ ke_return_keystring (gint keyID)
 	case XK_BackSpace:rv = g_strdup ("BackSpace");break;
 	case XK_Delete:rv = g_strdup ("Delete");break;
 	case XK_Escape:rv = g_strdup ("Escape");break;
+	case XK_Super_L:rv = g_strdup ("Super_L");break;
+	case XK_Super_R:rv = g_strdup ("Super_R");break;
+	case XK_Hyper_L:rv = g_strdup ("Hyper_L");break;
+	case XK_Hyper_R:rv = g_strdup ("Hyper_R");break;
+	case XK_Menu:rv = g_strdup ("Menu");break;	
         default:
     	    rv = NULL;
     }
@@ -553,6 +558,7 @@ ke_return_key (glong keyID)
 	case XK_KP_8:		layer_code = 8; break;
 	case XK_KP_9:		layer_code = 9; break;
 	case XK_KP_Decimal:	layer_code = 10; break;
+	case XK_KP_Separator:	layer_code = 10; break;
 	case XK_KP_Enter:	layer_code = 11; break;
 	case XK_KP_Add:		layer_code = 12; break;
 	case XK_KP_Subtract:	layer_code = 13; break;
@@ -1427,6 +1433,8 @@ ke_get_keypad_keycodes (void)
     keycodes [13] = XKeysymToKeycode (display, XK_KP_Subtract);
     keycodes [14] = XKeysymToKeycode (display, XK_KP_Multiply);
     keycodes [15] = XKeysymToKeycode (display, XK_KP_Divide);
+    /* Fix for bug #148774 - some kbds report XK_KP_Separator in numpad */
+    keycodes [16] = XKeysymToKeycode (display, XK_KP_Separator);
     	
     return keycodes;
 }
@@ -1459,7 +1467,12 @@ long keyecho_keysym[] = {
     XK_Page_Down,
     XK_BackSpace,
     XK_Delete,
-    XK_Escape
+    XK_Escape,
+    XK_Super_L,
+    XK_Super_R,    
+    XK_Hyper_L,
+    XK_Hyper_R,
+    XK_Menu
 };
 
 gchar*
