@@ -1805,7 +1805,8 @@ srl_event_is_reported (SRLEvent *event)
 	rv = TRUE;
     else if (srle_has_type (event, SRL_EVENT_FOCUS))
 	rv = srle_acc_has_state (event, SPI_STATE_FOCUSED) ||
-	     srle_acc_has_state (event, SPI_STATE_TRANSIENT);
+	     srle_acc_has_state (event, SPI_STATE_TRANSIENT) ||
+	     srle_acc_has_state (event, SPI_STATE_ACTIVE);
     else if (srle_has_type (event, SRL_EVENT_FOCUS1))
 	rv = TRUE;
     else if (srle_has_type (event, SRL_EVENT_FOCUS2))
